@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20251022';
+our $VERSION = '5.20260119';
 our %utilities;
 
 sub utilities {
@@ -2203,6 +2203,27 @@ my %delta = (
         removed => {
         }
     },
+    5.043005 => {
+        delta_from => 5.043004,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.043006 => {
+        delta_from => 5.043005,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.043007 => {
+        delta_from => 5.043006,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
